﻿//===============================================================================
// PJM Interconnection, LLC. Sprego Application
// Comments provided by Glenn Long
//===============================================================================

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter.Events;
using PJMBaseLibrary.Utilities.DateTimeFunctions;
using UIComposition.Views.CasesView;

namespace UIComposition.Views.HourlyRequestsView
{
    using System.Windows.Controls;
    using UIComposition.Infrastructure;
    using System.Collections.ObjectModel;
    using UIComposition.Controllers;
    using Microsoft.Practices.Unity;
    using UIComposition.Services;
    using Infragistics.Windows.Editors;
    using Infragistics.Windows.DataPresenter;
    using PJMBaseLibrary.Utilities.Logger;
    using PJMBaseLibrary.Utilities.ApplicationEnums;
    using UIComposition.UtilityClasses;
    using System.Reflection;

    /// <summary>
    /// Interaction logic for ConstraintsView.xaml
    /// </summary>

    public partial class HourlyReqView : UserControl, IHourlyReqView
    {
        private int index;
        private bool isLoaded;

        public HourlyReqView()
        {
            InitializeComponent();
            this.HourlyReq.LostFocus += new RoutedEventHandler(HourlyReq_LostFocus);            
        }

         

        void HourlyReq_LostFocus(object sender, RoutedEventArgs e)
        {
            ASClientCommands.HourlyReqIsLoaded = true;           
        }       

        public HourlyReqPresentationModel Model
        {
            get { return this.DataContext as HourlyReqPresentationModel; }
            set { this.DataContext = value; }
        }

        private void HourlyReq_AssigningFieldLayoutToItem(object sender, Infragistics.Windows.DataPresenter.Events.AssigningFieldLayoutToItemEventArgs e)
        {

            e.FieldLayout = this.HourlyReq.FieldLayouts[index];
            index++;

            if (index > 0) { index = 0; }

        }

        private void HourlyReq_RecordUpdated(object sender, RecordUpdatedEventArgs e)
        {
            ASEngine.BusinessObjects.Entities.HourlyReq o = (ASEngine.BusinessObjects.Entities.HourlyReq)e.Record.DataItem;

            UpdateBO(o);
        }

        public void UpdateBO(ASEngine.BusinessObjects.Entities.HourlyReq item)
        {
            SaveController.Instance.AddUpdate(typeof(ASEngine.BusinessObjects.Entities.HourlyReqs), item);

        }

        private void datePicker1_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            this.DataContext = null;
            IUnityContainer aContainer = ConnectionService.Instance.globalContainer;
            if (aContainer != null)
            {
                IHourlyReqPresenter hourlyReqPresenter = aContainer.Resolve<IHourlyReqPresenter>();

                hourlyReqPresenter.SetHourlyReqForDate(MKTHour.GetGMTDate(Convert.ToDateTime(datePicker1.SelectedDate)));
                this.DataContext = hourlyReqPresenter.View.Model;
            }
            ASClientCommands.RefreshCase = true;
        }

        private void btnRefreshMsg_Click(object sender, RoutedEventArgs e)
        {
            if (datePicker1.SelectedDate.HasValue == true)
            {
                this.DataContext = null;
                IUnityContainer aContainer = ConnectionService.Instance.globalContainer;
                if (aContainer != null)
                {
                    IHourlyReqPresenter hourlyReqPresenter = aContainer.Resolve<IHourlyReqPresenter>();

                    hourlyReqPresenter.SetHourlyReqForDate(MKTHour.GetGMTDate(Convert.ToDateTime(datePicker1.SelectedDate)));
                    this.DataContext = hourlyReqPresenter.View.Model;
                }
            }
            else
            {
                datePicker1.SelectedDate = DateTime.Today;
            }
            ASClientCommands.RefreshCase = true;
        }

        public static DateTime getLatestT2ApprovedCaseDate()
        {
            DateTime latestT2AppprovedDate = DateTime.Now.AddHours(2);           


            try
            {

                var casesList = UIComposition.Views.CasesView.CasesListView.T2CasesList;
                foreach (ASEngine.BusinessObjects.Entities.ASCaseControls cc in casesList)
                {
                foreach (ASEngine.BusinessObjects.Entities.ASCaseControl t2Case in cc)                    
                    {
                        if (t2Case.Tier2state == "Approved")
                        {
                            Console.Write(t2Case.Tier2state.ToString());
                            if (System.Convert.ToDecimal(t2Case.Tier2solutiontime.Value.AddHours(1).Hour) > System.Convert.ToDecimal(latestT2AppprovedDate.Hour))
                            {
                                latestT2AppprovedDate = t2Case.Tier2solutiontime.Value.AddHours(1);
                            }                           
                        }

                    }
                                       
                }                              

               
            }
            catch (Exception ex) { Logger.LogException(LogSourceType.ClientApplication, ex); }

            return latestT2AppprovedDate;
        }

  

    }

}
    
